@@ -4,9 +4,8 @@ use strict;
 use warnings;
 
 BEGIN
-  {
-    $App::FileTools::BulkRename::Common::VERSION
-      = substr '$$Version: 0.03 $$', 11, -3;
+  { our
+      $VERSION = substr '$$Version: 0.04 $$', 11, -3;
   }
 
 require Exporter;
